@@ -136,7 +136,7 @@ test_that("File client interface works",
 
     con <- rawConnection(raw(0), open="r+")
     download_azure_file(share, "iris.json", con)
-    iris3 <- as.data.frame(jsonlite::fromJSON(con))
+    iris3 <- as.data.frame(jsonlite::fromJSON(con), stringsAsFactors=TRUE)
     expect_identical(iris, iris3)
 
     # check existence
